﻿using Exam.ExamManages;

using Exam.Share;
using Exam.Share.Dtos.ExamManage;
using Exam.Share.ViewResponses.Exam;
using Hotline.Repository.SqlSugar.Interface;
using Hotline.Share.Dtos.ExamManages;
using Hotline.Share.Requests.Exam;
using Hotline.Share.ViewResponses.Exam;

namespace Exam.Application.Interface.Exam
{
    public interface IUserExamService:IQueryService<UserExamResultViewResponse,UserExamDto,UserExamPagedRequest>,IApiService<AddUserExamDto,UpdateUserExamDto,UserExam>
    {
        /// <summary>
        /// 交卷
        /// </summary>
        /// <param name="submitExamDto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        Task SubmitAsync(SubmitExamDto submitExamDto,CancellationToken cancellationToken);

        
        /// <summary>
        /// 阅卷
        /// </summary>
        /// <param name="gradingExtamItemDto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        Task<GradingExamQuestionDto> GradingAsync(GradingExtamItemDto gradingExtamItemDto, CancellationToken cancellationToken);

        /// <summary>
        /// 获取考试试题类型和Id
        /// </summary>
        /// <param name="examQuestionRequest"></param>
        /// <returns></returns>
        Task<List<ExamQuestionViewResponse>> GetExamQuestionViewResponses(ExamQuestionGroupRequest examQuestionGroupRequest);

        /// <summary>
        /// 获取考试试题
        /// </summary>
        /// <param name="examQuestionRequest"></param>
        /// <returns></returns>
        Task<ExamQuestionDto> GetExamQuestionDto(ExamQuestionRequest examQuestionRequest);

        /// <summary>
        /// 初次考试
        /// </summary>
        /// <param name="addUserExamItemDto"></param>
        /// <returns></returns>
        Task<UserExamQuestionDto> ExamAsync(AddUserExamItemDto addUserExamItemDto, CancellationToken cancellationToken);

        /// <summary>
        /// 修改考试选项
        /// </summary>
        /// <param name="addUserExamItemDto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        Task<UserExamQuestionDto> UpdateExamAsync(UpdateUserExamItemDto updateUserExamItemDto, CancellationToken cancellationToken);

        /// <summary>
        /// 开始考试
        /// </summary>
        /// <param name="startUserExamDto"></param>
        /// <param name="CancellationToken"></param>
        /// <returns></returns>
        Task StartUserExamAsync(StartUserExamDto startUserExamDto,CancellationToken cancellationToken);

        /// <summary>
        /// 完成阅卷
        /// </summary>
        /// <param name="gradingExtamDto"></param>
        /// <param name="cancellationToken"></param>
        /// <returns></returns>
        Task CompleteGradingAsync(GradingExamDto gradingExtamDto,CancellationToken cancellationToken);

        /// <summary>
        /// 获取阅卷试题
        /// </summary>
        /// <param name="gradingExamRequest"></param>
        /// <returns></returns>
        Task<List<GradingExamQuestionDto>> GetGradingExamQuestion(GradingExamRequest gradingExamRequest);
    }
}
