﻿using Exam.Infrastructure.Data.Entity;
using Exam.Infrastructure.Extensions;
using Exam.Infrastructure.Web.Utilities;
using Exam.TestPapers;
using Hotline.Share.Requests.Exam;
using JiebaNet.Segmenter.Common;
using System.Linq.Expressions;

namespace Hotline.Application.Exam.QueryExtensions.TestPapers
{
    public static class TestPaperQueryExtensions
    {
        public static Expression<Func<TestPaper,bool>> GetExpression(this TestPaperPagedRequest testPaperPagedRequest)
        {
            Expression<Func<TestPaper, bool>> expression = m => m.Id != null;

            expression = ExpressionableUtility.CreateExpression<TestPaper>()
                .AndIF(testPaperPagedRequest.Name.IsNotNullOrEmpty(), x => x.Name.Contains(testPaperPagedRequest.Name))
                .AndIF(testPaperPagedRequest.Code.IsNotNullOrEmpty(), x => x.Code.Contains(testPaperPagedRequest.Code))
                .AndIF(testPaperPagedRequest.Status.IsNotNull(), x => x.Status == testPaperPagedRequest.Status)
                .AndIF(testPaperPagedRequest.ExamMode.IsNotNull(), x => x.Mode == testPaperPagedRequest.ExamMode)
                .AndIF(testPaperPagedRequest.ExamType.IsNotNull(), x => x.ExamType == testPaperPagedRequest.ExamType)
                .ToExpression();

            return expression;
        }

        public static Expression<Func<TestPaperRule, bool>> GetTestPaperRuleExpression(this EntityQueryRequest entityQueryRequest)
        {
            Expression<Func<TestPaperRule, bool>> expression = m => m.Id != null;

            expression = ExpressionableUtility.CreateExpression<TestPaperRule>()
                .AndIF(entityQueryRequest.Id.IsNotNullOrEmpty(), x => x.TestPaperId == entityQueryRequest.Id)
                .AndIF(entityQueryRequest.Ids.IsNotNull(), x => entityQueryRequest.Ids.Contains(x.TestPaperId))
                .ToExpression();

            return expression;
        }

        public static Expression<Func<TestPaper,bool>> GetTestPaperCountExpression(this TestPaperQuestionCountRequest testPaperQuestionCountRequest)
        {
            Expression<Func<TestPaper, bool>> expression = m => m.Id != null;

            expression = ExpressionableUtility.CreateExpression<TestPaper>()
               .AndIF(testPaperQuestionCountRequest.TestPaperId.IsNotNullOrEmpty(), x => x.Id == testPaperQuestionCountRequest.TestPaperId)
               .ToExpression();

            return expression;
        }

        public static Expression<Func<TestPaperRule,bool>> GetTestPaperRuleExpression(this TestPaperQuestionCountRequest testPaperQuestionCountRequest)
        {
            Expression<Func<TestPaperRule, bool>> expression = m => m.Id != null;

            expression = ExpressionableUtility.CreateExpression<TestPaperRule>()
               .AndIF(testPaperQuestionCountRequest.TestPaperId.IsNotNullOrEmpty(), x => x.TestPaperId == testPaperQuestionCountRequest.TestPaperId)
               .ToExpression();

            return expression;
        }

        public static Expression<Func<TestPaperItem,bool>> GetTestPaperItemsExpression(this TestPaperQuestionCountRequest testPaperQuestionCountRequest)
        {
            Expression<Func<TestPaperItem, bool>> expression = m => m.Id != null;

            expression = ExpressionableUtility.CreateExpression<TestPaperItem>()
               .AndIF(testPaperQuestionCountRequest.TestPaperId.IsNotNullOrEmpty(), x => x.TestPaperId == testPaperQuestionCountRequest.TestPaperId)
               .ToExpression();

            return expression;
        }
    }
}
